### devrun (v0.2.3)

**Purpose**: Consolidated development tool runner agent with integrated tool documentation for pytest, pyright, ruff, prettier, make, and gt

**Artifacts**:

- agent: agents/devrun/devrun.md
- doc: docs/devrun/tools/gt.md, docs/devrun/tools/make.md, docs/devrun/tools/prettier.md, docs/devrun/tools/pyright.md, docs/devrun/tools/pytest.md, docs/devrun/tools/ruff.md

**Usage**:

- Use Task tool with subagent_type="devrun"
